| Title: | Calculate Medicare Reimbursement |
|---|---|
| Description: | Uses the 'CMS' application programming interface <https://dnav.cms.gov/api/healthdata> to provide users databases containing yearly Medicare reimbursement rates in the United States. Data can be acquired for the entire United States or only for specific localities. Currently, support is only provided for the Medicare Physician Fee Schedule, but support will be expanded for other 'CMS' databases in future versions. |
| Authors: | Vigneshwar Subramanian [aut, cre], Raoul Wadhwa [aut], Milind Desai [ctb] |
| Maintainer: | Vigneshwar Subramanian <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-05-21 07:48:09 UTC |
| Source: | https://github.com/subramv/cms |
Uses the CMS API to provide useRs databases containing yearly Medicare reimbursement rates in the United States. Data can be acquired for the entire United States or only for specific localities. Currently, support is only provided for the Medicare Physician Fee Schedule (MPFS), but support will be expanded for other CMS databases in future versions.
Use the CMS API to download the MPFS database for any year between 2014 and 2020, inclusive.
get_mpfs(year, storage_path, keep_downloads = TRUE, locality)get_mpfs(year, storage_path, keep_downloads = TRUE, locality)
year |
integer (min = 14; max = 20) indicating MPFS database year |
storage_path |
path to storing downloaded files (temporarily if 'keep_downloads' equals 'FALSE') |
keep_downloads |
if 'TRUE', stores compressed CMS data to prevent re-downloading; if 'FALSE', deletes intermediate data after loading into R |
locality |
7-digit HCFS identification number; if not specified, will return entire MPFS database (all localities) |
MPFS database for respective year and localities (data frame)
## Not run: # get entire MPFS database for 2020 mpfs20 <- get_mpfs(20, storage_path = 'storage', keep_downloads = TRUE) # get 2019 MPFS database only for carrier 15202 and locality 00 mpfs19 <- get_mpfs(19, storage_path = 'storage', locality = '1520200') ## End(Not run)## Not run: # get entire MPFS database for 2020 mpfs20 <- get_mpfs(20, storage_path = 'storage', keep_downloads = TRUE) # get 2019 MPFS database only for carrier 15202 and locality 00 mpfs19 <- get_mpfs(19, storage_path = 'storage', locality = '1520200') ## End(Not run)
Asterisk indicates that payment locality is serviced by two carriers.
locality_dictlocality_dict
data frame with 113 rows and 5 columns:
character; 5-digit carrier ID
character; 2-digit locality ID
character; uppercase, full U.S. state name
character; description of fee schedule area
character; counties included in Fee Schedule Area
https://www.cms.gov/Medicare/Medicare-Fee-for-Service-Payment/PhysicianFeeSched/Locality
2020 Physician Fee Schedule, Ohio
mpfs20_ohmpfs20_oh
data frame with 8994 rows and 15 columns:
numeric; 4-digit year
character; 5-digit carrier ID
character; 2-digit locality ID
character; CPT or level 2 HCPCS code for procedure
factor; payment schedule modifier
character; Professional Component/Technical Component Indicator
character; Medicare status code (e.g. A = Active code)
character; indicator of payment adjustment rules for multiple procedures
numeric; multiple procedure therapy reduction amount (non-institutional)
numeric; multiple procedure therapy reduction amount (institutional)
character; indicator as to whether Outpatient Prospective Payment System applies
numeric; reimbursement for procedure performed in a facility setting
numeric; reimbursement for procedure performed in a non-facility setting
numeric; reimbursement for procedure performed in a facility setting if OPPS applies
numeric; reimbursement for procedure performed in a non-facility setting if OPPS applies